@@ -305,27 +305,28 @@ class PanelHandler:
 
         return gene_dict
 
-    def panel_to_genes(self, panel_id=None, panel_name=None):
+    def panel_to_genes(self, panel_id=None, panel_name=None, gene_format="symbol"):
         """Return all hgnc_ids for a given gene panel
 
         Args:
             panel_id(ObjectId): _id of a gene panel (to collect specific version of a panel)
             panel_name(str): Name of a gene panel (to collect latest version of a panel)
+            gene_format(str): either "symbol" or "hgnc_id"
 
         Returns:
-            gene_list(list): a list of hgnc terms
+            gene_list(list): a list of hgnc terms (either symbols or HGNC ids)
 
         """
-        gene_list = []
         panel_obj = None
         if panel_id:
             panel_obj = self.panel(panel_id)
         elif panel_name:
             panel_obj = self.gene_panel(panel_name)
 
-        if panel_obj is not None:
-            gene_list = [gene_obj.get("symbol", "") for gene_obj in panel_obj.get("genes", [])]
+        if panel_obj is None:
+            return []
 
+        gene_list = [gene_obj.get(gene_format, "") for gene_obj in panel_obj.get("genes", [])]
         return gene_list
 
     def update_panel(self, panel_obj, version=None, date_obj=None, maintainer=None):
