@@ -19,20 +19,17 @@ Copyright (c) 2015 __MoonsoInc__. All rights reserved.
 import logging
 
 import click
-from flask.cli import with_appcontext, current_app
-from pprint import pprint as pp
+from flask.cli import current_app, with_appcontext
 
-from scout.load import load_hgnc_genes, load_transcripts, load_exons
+from scout.load import load_hgnc_genes, load_transcripts
 from scout.server.extensions import store
-from scout.utils.link import link_genes
-from scout.utils.handle import get_file_handle
 from scout.utils.scout_requests import (
-    fetch_mim_files,
+    fetch_ensembl_genes,
+    fetch_ensembl_transcripts,
+    fetch_exac_constraint,
     fetch_genes_to_hpo_to_disease,
     fetch_hgnc,
-    fetch_ensembl_genes,
-    fetch_exac_constraint,
-    fetch_ensembl_transcripts,
+    fetch_mim_files,
 )
 
 LOG = logging.getLogger(__name__)
@@ -83,8 +80,8 @@ def genes(build, api_key):
     hgnc_lines = fetch_hgnc()
     exac_lines = fetch_exac_constraint()
 
-    for build in builds:
-        ensembl_genes = fetch_ensembl_genes(build=build)
+    for genome_build in builds:
+        ensembl_genes = fetch_ensembl_genes(build=genome_build)
 
         # load the genes
         hgnc_genes = load_hgnc_genes(
@@ -95,7 +92,7 @@ def genes(build, api_key):
             mim2gene_lines=mim_files.get("mim2genes"),
             genemap_lines=mim_files.get("genemap2"),
             hpo_lines=hpo_genes,
-            build=build,
+            build=genome_build,
         )
 
         ensembl_genes = {}
@@ -104,9 +101,9 @@ def genes(build, api_key):
             ensembl_genes[ensembl_id] = gene_obj
 
         # Fetch the transcripts from ensembl
-        ensembl_transcripts = fetch_ensembl_transcripts(build=build)
+        ensembl_transcripts = fetch_ensembl_transcripts(build=genome_build)
 
-        transcripts = load_transcripts(adapter, ensembl_transcripts, build, ensembl_genes)
+        transcripts = load_transcripts(adapter, ensembl_transcripts, genome_build, ensembl_genes)
 
     adapter.update_indexes()
 
