@@ -1,20 +1,15 @@
 import copy
 import datetime
 import logging
+from fractions import Fraction
 from pathlib import Path
 from pprint import pprint as pp
-from fractions import Fraction
 
 from ped_parser import FamilyParser
 
 from scout.constants import PHENOTYPE_MAP, REV_PHENOTYPE_MAP, REV_SEX_MAP, SEX_MAP
 from scout.exceptions import ConfigError, PedigreeError
-
-from scout.parse.peddy import (
-    parse_peddy_ped,
-    parse_peddy_ped_check,
-    parse_peddy_sex_check,
-)
+from scout.parse.peddy import parse_peddy_ped, parse_peddy_ped_check, parse_peddy_sex_check
 from scout.parse.smn import parse_smn_file
 from scout.utils.date import get_date
 
@@ -63,6 +58,8 @@ def parse_case_data(
     multiqc=None,
     cnv_report=None,
     coverage_qc_report=None,
+    gene_fusion_report=None,
+    gene_fusion_report_research=None,
 ):
     """Parse all data necessary for loading a case into scout
 
@@ -84,6 +81,8 @@ def parse_case_data(
         multiqc(str): Path to dir with multiqc information
         cnv_report: Path to pdf file with CNV report
         coverage_qc_report: Path to html file with coverage and qc report
+        gene_fusion_report: Path to the gene fusions report
+        gene_fusion_report_research: Path to the gene fusions research report
 
     Returns:
         config_data(dict): Holds all the necessary information for loading
@@ -148,6 +147,14 @@ def parse_case_data(
     config_data["coverage_qc_report"] = (
         coverage_qc_report if coverage_qc_report else config_data.get("coverage_qc_report")
     )
+    config_data["gene_fusion_report"] = (
+        gene_fusion_report if gene_fusion_report else config_data.get("gene_fusion_report")
+    )
+    config_data["gene_fusion_report_research"] = (
+        gene_fusion_report_research
+        if gene_fusion_report_research
+        else config_data.get("gene_fusion_report_research")
+    )
 
     config_data["rank_model_version"] = str(config_data.get("rank_model_version", ""))
     config_data["rank_score_threshold"] = config_data.get("rank_score_threshold", 0)
@@ -525,6 +532,8 @@ def parse_case(config):
         "delivery_report": config.get("delivery_report"),
         "cnv_report": config.get("cnv_report"),
         "coverage_qc_report": config.get("coverage_qc_report"),
+        "gene_fusion_report": config.get("gene_fusion_report"),
+        "gene_fusion_report_research": config.get("gene_fusion_report_research"),
         "multiqc": config.get("multiqc"),
         "track": config.get("track", "rare"),
     }
