@@ -7,17 +7,17 @@ import os
 
 import query_phenomizer
 import requests
-from bson.objectid import ObjectId
 from bs4 import BeautifulSoup
-from flask import current_app, url_for, flash
+from bson.objectid import ObjectId
+from flask import current_app, flash, url_for
 from flask_login import current_user
 from flask_mail import Message
 from xlsxwriter import Workbook
 
 from scout.constants import (
     CANCER_PHENOTYPE_MAP,
-    MT_EXPORT_HEADER,
     MT_COV_STATS_HEADER,
+    MT_EXPORT_HEADER,
     PHENOTYPE_GROUPS,
     PHENOTYPE_MAP,
     SEX_MAP,
@@ -31,14 +31,9 @@ from scout.constants.variant_tags import (
     MANUAL_RANK_OPTIONS,
 )
 from scout.export.variant import export_mt_variants
-from scout.server.extensions import store
-from scout.parse.matchmaker import (
-    genomic_features,
-    hpo_terms,
-    omim_terms,
-    parse_matches,
-)
+from scout.parse.matchmaker import genomic_features, hpo_terms, omim_terms, parse_matches
 from scout.server.blueprints.variant.controllers import variant as variant_decorator
+from scout.server.extensions import store
 from scout.server.utils import institute_and_case
 from scout.utils.matchmaker import matchmaker_request
 from scout.utils.scout_requests import post_request_json
@@ -454,7 +449,8 @@ def mt_coverage_stats(individuals, ref_chrom="14"):
 
 def mt_excel_files(store, case_obj, temp_excel_dir):
     """Collect MT variants and format line of a MT variant report
-    to be exported in excel format
+    to be exported in excel format. Create mt excel files, one for each sample,
+    in a temporary directory.
 
     Args:
         store(adapter.MongoAdapter)
@@ -531,6 +527,27 @@ def update_synopsis(store, institute_obj, case_obj, user_obj, new_synopsis):
         store.update_synopsis(institute_obj, case_obj, user_obj, link, content=new_synopsis)
 
 
+def _update_case(store, case_obj, user_obj, institute_obj, verb):
+    """Update case with new sample data, and create an associated event"""
+    store.update_case(case_obj, keep_date=True)
+
+    link = url_for(
+        "cases.case",
+        institute_id=institute_obj["_id"],
+        case_name=case_obj["display_name"],
+    )
+
+    store.create_event(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link=link,
+        category="case",
+        verb=verb,
+        subject=case_obj["display_name"],
+    )
+
+
 def update_individuals(store, institute_obj, case_obj, user_obj, ind, age, tissue):
     """Handle update of individual data (age and/or Tissue type) for a case"""
 
@@ -545,24 +562,9 @@ def update_individuals(store, institute_obj, case_obj, user_obj, ind, age, tissu
                 subject["tissue_type"] = tissue
 
     case_obj["individuals"] = case_individuals
-    # update case with new individual data
-    store.update_case(case_obj, keep_date=True)
 
-    # create an associated event
-    link = url_for(
-        "cases.case",
-        institute_id=institute_obj["_id"],
-        case_name=case_obj["display_name"],
-    )
-    store.create_event(
-        institute=institute_obj,
-        case=case_obj,
-        user=user_obj,
-        link=link,
-        category="case",
-        verb="update_individual",
-        subject=case_obj["display_name"],
-    )
+    verb = "update_individual"
+    _update_case(store, case_obj, user_obj, institute_obj, verb)
 
 
 def update_cancer_samples(
@@ -585,36 +587,23 @@ def update_cancer_samples(
                 sample["tumor_purity"] = None
 
     case_obj["individuals"] = case_samples
-    # update case with new sample data
-    store.update_case(case_obj, keep_date=True)
 
-    # create an associated event
-    link = url_for(
-        "cases.case",
-        institute_id=institute_obj["_id"],
-        case_name=case_obj["display_name"],
-    )
-
-    store.create_event(
-        institute=institute_obj,
-        case=case_obj,
-        user=user_obj,
-        link=link,
-        category="case",
-        verb="update_sample",
-        subject=case_obj["display_name"],
-    )
+    verb = "update_sample"
+    _update_case(store, case_obj, user_obj, institute_obj, verb)
 
 
-def phenotypes_genes(store, case_obj):
+def phenotypes_genes(store, case_obj, is_clinical=True):
     """Generate a dictionary consisting of phenotype terms with associated genes from the case HPO panel
 
     Args:
         store(adapter.MongoAdapter)
         case_obj(dict): models.Case
+        is_clinical(bool): if True, only list genes from HPO that are among the case clinical_symbols
 
     Returns:
         hpo_genes(dict): a dictionary with HPO term IDs as keys and HPO terms and genes as values
+                      If the dynamic phenotype panel is empty, or has been intersected to some level,
+                      use dynamic gene list directly instead.
     """
     build = case_obj["genome_build"]
     # Make sure build is either "37" or "38"
@@ -623,11 +612,20 @@ def phenotypes_genes(store, case_obj):
     else:
         build = "37"
     dynamic_gene_list = [gene["hgnc_id"] for gene in case_obj.get("dynamic_gene_list", [])]
-    by_phenotype = True  # display genes by phenotype
-    unique_genes = set()
+
     hpo_genes = {}
+
+    clinical_symbols = store.clinical_symbols(case_obj) if is_clinical else None
+    unique_genes = hpo_genes_from_dynamic_gene_list(case_obj, is_clinical, clinical_symbols)
+
+    by_phenotype = True  # display genes by phenotype
+    hpo_gene_list = case_obj.get("dynamic_panel_phenotypes", [])
+    if not hpo_gene_list and dynamic_gene_list:
+        by_phenotype = False
+
+    all_hpo_gene_list_genes = set()
     # Loop over the dynamic phenotypes of a case
-    for hpo_id in case_obj.get("dynamic_panel_phenotypes", []):
+    for hpo_id in hpo_gene_list:
         hpo_term = store.hpo_term(hpo_id)
         # Check that HPO term exists in database
         if hpo_term is None:
@@ -640,27 +638,62 @@ def phenotypes_genes(store, case_obj):
             if gene_obj is None:
                 continue
             if gene_id not in dynamic_gene_list:
-                # gene was filtered out because min matching phenotypes > 1
+                # gene was filtered out because min matching phenotypes > 1 (or the panel was generated with older genotype-phenotype mapping)
                 by_phenotype = False  # do not display genes by phenotype
                 continue
             add_symbol = gene_obj.get("hgnc_symbol", f"hgnc:{gene_id}")
+            if is_clinical and (add_symbol not in clinical_symbols):
+                continue
             gene_list.append(add_symbol)
-            unique_genes.add(add_symbol)
+            all_hpo_gene_list_genes.add(add_symbol)
 
         hpo_genes[hpo_id] = {
             "description": hpo_term.get("description"),
             "genes": ", ".join(sorted(gene_list)),
         }
 
+    if by_phenotype is True:
+        # if some gene was manually added (or is left on dynamic panel for other reasons)
+        non_hpo_genes = unique_genes - all_hpo_gene_list_genes
+        if len(non_hpo_genes) > 0:
+            hpo_genes["Analysed genes"] = {
+                "description": "Non HPO panel genes",
+                "genes": ", ".join(sorted(non_hpo_genes)),
+            }
+
     if by_phenotype is False:
         hpo_genes = {}
         hpo_genes["Analysed genes"] = {
             "description": "HPO panel",
             "genes": ", ".join(sorted(unique_genes)),
         }
+
     return hpo_genes
 
 
+def hpo_genes_from_dynamic_gene_list(case_obj, is_clinical, clinical_symbols):
+    """
+    Case where dynamic_panel_phenotypes is empty, perhaps because user has added custom genes to HPO panel
+
+    Args:
+        case_obj(dict): models.Case)
+        is_clinical(bool): if True, only list genes from HPO that are among the case clinical_symbols
+        clinical_symbols(set): set of clinical symbols
+    Returns:
+        hpo_genes(set):
+    """
+
+    gene_list = [
+        gene.get("hgnc_symbol") or str(gene["hgnc_id"]) for gene in case_obj["dynamic_gene_list"]
+    ]
+
+    unique_genes = set(gene_list)
+    if is_clinical:
+        unique_genes = unique_genes.intersection(set(clinical_symbols))
+
+    return unique_genes
+
+
 def hpo_diseases(username, password, hpo_ids, p_value_treshold=1):
     """Return the list of HGNC symbols that match annotated HPO terms.
 
@@ -865,7 +898,7 @@ def beacon_remove(case_id):
     resp = post_request_json("/".join([request_url, "delete"]), data, req_headers)
     flash_color = "success"
     if resp.get("status_code") == 200:
-        store.case_collection.update({"_id": case_obj["_id"]}, {"$unset": {"beacon": 1}})
+        store.case_collection.update_one({"_id": case_obj["_id"]}, {"$unset": {"beacon": 1}})
     else:
         flash_color = "warning"
     flash(f"Beacon responded:{resp['message']}", flash_color)
