@@ -16,10 +16,12 @@ from scout.constants import (
     ACMG_MAP,
     ACMG_OPTIONS,
     CALLERS,
+    CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
     CANCER_TIER_OPTIONS,
+    CHROMOSOMES,
+    CHROMOSOMES_38,
     CLINSIG_MAP,
     DISMISS_VARIANT_OPTIONS,
-    CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
     MANUAL_RANK_OPTIONS,
     MOSAICISM_OPTIONS,
     SEVERE_SO_TERMS,
@@ -29,9 +31,8 @@ from scout.constants import (
 from scout.constants.acmg import ACMG_CRITERIA
 from scout.constants.variants_export import EXPORT_HEADER, VERIFIED_VARIANTS_HEADER
 from scout.export.variant import export_verified_variants
-from scout.server.blueprints.genes.controllers import gene
-from scout.server.blueprints.variant.utils import predictions, clinsig_human
-from scout.server.links import str_source_link, ensembl, cosmic_link
+from scout.server.blueprints.variant.utils import clinsig_human, predictions
+from scout.server.links import cosmic_link, ensembl, str_source_link
 from scout.server.utils import (
     case_append_alignments,
     institute_and_case,
@@ -45,6 +46,13 @@ from .forms import CancerFiltersForm, FiltersForm, StrFiltersForm, SvFiltersForm
 LOG = logging.getLogger(__name__)
 
 
+def populate_chrom_choices(form, case_obj):
+    """Populate the option of the chromosome select accordig to the case genome build"""
+    # Populate chromosome choices
+    chromosomes = CHROMOSOMES if "37" in str(case_obj.get("genome_build")) else CHROMOSOMES_38
+    form.chrom.choices = [("", "All")] + [(chrom, chrom) for chrom in chromosomes]
+
+
 def variants(store, institute_obj, case_obj, variants_query, variant_count, page=1, per_page=50):
     """Pre-process list of variants."""
 
@@ -383,7 +391,7 @@ def download_variants(store, case_obj, variant_objs):
     headers.add(
         "Content-Disposition",
         "attachment",
-        filename=str(case_obj["display_name"]) + "-filtered_sv-variants.csv",
+        filename=str(case_obj["display_name"]) + "-filtered-variants.csv",
     )
     # return a csv with the exported variants
     return Response(
@@ -419,7 +427,7 @@ def variant_export_lines(store, case_obj, variants_query):
 
         # if variant is in genes
         if gene_list is not None and len(gene_list) > 0:
-            gene_info = variant_export_genes_info(store, gene_list)
+            gene_info = variant_export_genes_info(store, gene_list, case_obj.get("genome_build"))
             variant_line += gene_info
         else:
             empty_col = 0
@@ -445,11 +453,52 @@ def variant_export_lines(store, case_obj, variants_query):
     return export_variants
 
 
-def variant_export_genes_info(store, gene_list):
+def match_gene_txs_variant_txs(variant_gene, hgnc_gene):
+    """Match gene transcript with variant transcript to extract primary and canonical tx info
+
+    Args:
+        variant_gene(dict): A gene dictionary with limited info present in variant.genes.
+                        contains info on which transcript is canonical, hgvs and protein changes
+        hgnc_gene(dict): A gene object obtained from the database containing a complete list of transcripts.
+
+    Returns:
+        canonical_txs, primary_txs(tuple): columns containing canonical and primary transcript info
+    """
+    canonical_txs = []
+    primary_txs = []
+
+    for tx in hgnc_gene.get("transcripts", []):
+        tx_id = tx["ensembl_transcript_id"]
+
+        # collect only primary of refseq trancripts from hgnc_gene gene
+        if not tx.get("refseq_identifiers") and tx.get("is_primary") is False:
+            continue
+
+        for var_tx in variant_gene.get("transcripts", []):
+            if var_tx["transcript_id"] != tx_id:
+                continue
+
+            tx_refseq = tx.get("refseq_id")
+            hgvs = var_tx.get("coding_sequence_name") or "-"
+            pt_change = var_tx.get("protein_sequence_name") or "-"
+
+            # collect info from primary transcripts
+            if tx_refseq in hgnc_gene.get("primary_transcripts"):
+                primary_txs.append("/".join([tx_refseq or tx_id, hgvs, pt_change]))
+
+            # collect info from canonical transcript
+            if var_tx.get("is_canonical") is True:
+                canonical_txs.append("/".join([tx_refseq or tx_id, hgvs, pt_change]))
+
+    return canonical_txs, primary_txs
+
+
+def variant_export_genes_info(store, gene_list, genome_build="37"):
     """Adds gene info to a list of fields corresponding to a variant to be exported.
 
     Args:
-        gene_list(list) A list of gene objects contained in the variant
+        gene_list(list) A list of gene objects (with limited info) contained in the variant
+        genome_build(str): genome build to export gene list to
 
     Returns:
         gene_info(list) A list of gene-relates string info
@@ -457,35 +506,24 @@ def variant_export_genes_info(store, gene_list):
     gene_ids = []
     gene_names = []
     canonical_txs = []
-    hgvs_c = []
-    pt_c = []
-
+    primary_txs = []
     gene_info = []
 
     for gene_obj in gene_list:
         hgnc_id = gene_obj["hgnc_id"]
-        gene_name = gene(store, hgnc_id)["symbol"]
-
         gene_ids.append(hgnc_id)
-        gene_names.append(gene_name)
+        hgnc_gene = store.hgnc_gene(hgnc_id, genome_build)
+        if hgnc_gene is None:
+            continue
+        gene_names.append(hgnc_gene.get("hgnc_symbol"))
 
-        if gene_obj.get("canonical_transcript"):
-            canonical_txs.append(gene_obj.get("canonical_transcript"))
+        gene_canonical_txs, gene_primary_txs = match_gene_txs_variant_txs(gene_obj, hgnc_gene)
 
-        hgvs_nucleotide = "-"
-        protein_change = "-"
-        # gather HGVS info from gene transcripts
+        canonical_txs += gene_canonical_txs
+        primary_txs += gene_primary_txs
 
-        transcripts_list = gene_obj.get("transcripts")
-        for transcript_obj in transcripts_list:
-            if transcript_obj["transcript_id"] == gene_obj.get("canonical_transcript"):
-                hgvs_nucleotide = transcript_obj.get("coding_sequence_name") or "-"
-                protein_change = transcript_obj.get("protein_sequence_name") or "-"
-        hgvs_c.append(hgvs_nucleotide)
-        pt_c.append(protein_change)
-
-    for item in [gene_ids, gene_names, canonical_txs, hgvs_c, pt_c]:
-        gene_info.append(";".join(str(x) for x in item))
+    for item in [gene_ids, gene_names, canonical_txs, primary_txs]:
+        gene_info.append(" | ".join(str(x) for x in item))
 
     return gene_info
 
@@ -776,14 +814,33 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
     # populate available panel choices
     form.gene_panels.choices = gene_panel_choices(institute_obj, case_obj)
 
-    # check if supplied gene symbols exist
+    form = update_form_hgnc_symbols(store, case_obj, form)
+
+    return form
+
+
+def update_form_hgnc_symbols(store, case_obj, form):
+    """Update variants filter form with HGNC symbols from HPO, and check if any non-clinical genes for the case were
+    requested. If so, flash a warning to the user.
+
+    Accepts:
+        store(adapter.MongoAdapter)
+        case_obj(dict)
+        form(FiltersForm)
+
+    Returns:
+        form(FiltersForm)
+    """
+
     hgnc_symbols = []
     non_clinical_symbols = []
     not_found_symbols = []
     not_found_ids = []
-    if (form.hgnc_symbols.data) and len(form.hgnc_symbols.data) > 0:
-        is_clinical = form.data.get("variant_type", "clinical") == "clinical"
-        clinical_symbols = store.clinical_symbols(case_obj) if is_clinical else None
+    updated_hgnc_symbols = []
+
+    # retrieve current symbols from form
+    if form.hgnc_symbols.data:
+        # if symbols are numeric HGNC id, translate to current symbols
         for hgnc_symbol in form.hgnc_symbols.data:
             if hgnc_symbol.isdigit():
                 hgnc_gene = store.hgnc_gene(int(hgnc_symbol), case_obj["genome_build"])
@@ -791,25 +848,10 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
                     not_found_ids.append(hgnc_symbol)
                 else:
                     hgnc_symbols.append(hgnc_gene["hgnc_symbol"])
-            elif sum(1 for i in store.hgnc_genes(hgnc_symbol)) == 0:
-                not_found_symbols.append(hgnc_symbol)
-            elif is_clinical and (hgnc_symbol not in clinical_symbols):
-                non_clinical_symbols.append(hgnc_symbol)
             else:
                 hgnc_symbols.append(hgnc_symbol)
 
-    if not_found_ids:
-        flash("HGNC id not found: {}".format(", ".join(not_found_ids)), "warning")
-    if not_found_symbols:
-        flash("HGNC symbol not found: {}".format(", ".join(not_found_symbols)), "warning")
-    if non_clinical_symbols:
-        flash(
-            "Gene not included in clinical list: {}".format(", ".join(non_clinical_symbols)),
-            "warning",
-        )
-    form.hgnc_symbols.data = hgnc_symbols
-
-    # handle HPO gene list separately
+    # add HPO genes to list, if they were missing
     if "hpo" in form.data["gene_panels"]:
         hpo_symbols = list(
             set(term_obj["hgnc_symbol"] for term_obj in case_obj["dynamic_gene_list"])
@@ -817,7 +859,35 @@ def populate_sv_filters_form(store, institute_obj, case_obj, category, request_o
 
         current_symbols = set(hgnc_symbols)
         current_symbols.update(hpo_symbols)
-        form.hgnc_symbols.data = list(current_symbols)
+
+        hgnc_symbols = list(current_symbols)
+
+    # check if supplied gene symbols exist and are clinical
+    is_clinical = form.data.get("variant_type", "clinical") == "clinical"
+    clinical_symbols = store.clinical_symbols(case_obj) if is_clinical else None
+    for hgnc_symbol in hgnc_symbols:
+        if sum(1 for i in store.hgnc_genes(hgnc_symbol)) == 0:
+            not_found_symbols.append(hgnc_symbol)
+        elif is_clinical and (hgnc_symbol not in clinical_symbols):
+            non_clinical_symbols.append(hgnc_symbol)
+        else:
+            updated_hgnc_symbols.append(hgnc_symbol)
+
+    errors = {
+        "non_clinical_symbols": {
+            "alert": "Gene not included in clinical list",
+            "gene_list": non_clinical_symbols,
+        },
+        "not_found_symbols": {"alert": "HGNC symbol not found", "gene_list": not_found_symbols},
+        "not_found_ids": {"alert": "HGNC id not found", "gene_list": not_found_ids},
+    }
+
+    # warn user
+    for error, item in errors.items():
+        if item["gene_list"]:
+            flash(f"{item['alert']}: {item['gene_list']}", "warning")
+
+    form.hgnc_symbols.data = sorted(updated_hgnc_symbols)
 
     return form
 
@@ -899,6 +969,14 @@ def reset_all_dimissed(store, institute_obj, case_obj):
         case_obj(dict): a case dictionary
     """
     evaluated_vars = store.evaluated_variants(case_id=case_obj["_id"])
+    user_obj = store.user(current_user.email)
+    # Create an associated case-level event
+    link = url_for(
+        "cases.case", institute_id=institute_obj["_id"], case_name=case_obj["display_name"]
+    )
+    store.order_dismissed_variants_reset(institute_obj, case_obj, user_obj, link)
+
+    # Reset dismissed for each single dismissed variant
     for variant in evaluated_vars:
         if not variant.get("dismiss_variant"):  # not a dismissed variant
             continue
@@ -909,8 +987,7 @@ def reset_all_dimissed(store, institute_obj, case_obj):
             case_name=case_obj["display_name"],
             variant_id=variant["_id"],
         )
-        user = store.user(current_user.email)
-        store.update_dismiss_variant(institute_obj, case_obj, user, link, variant, [])
+        store.update_dismiss_variant(institute_obj, case_obj, user_obj, link, variant, [])
 
 
 def dismiss_variant_list(store, institute_obj, case_obj, link_page, variants_list, dismiss_reasons):
