@@ -1,6 +1,7 @@
-from flask import current_app
 from pprint import pprint as pp
 
+from flask import current_app
+
 from scout.constants import SPIDEX_HUMAN
 from scout.utils.convert import amino_acid_residue_change_3_to_1
 
@@ -371,8 +372,10 @@ def get_variant_links(variant_obj, build=None):
         decipher_link=decipher_link(variant_obj, build),
         ensembl_link=ensembl_link(variant_obj, build),
         alamut_link=alamut_link(variant_obj, build),
+        mitomap_link=mitomap_link(variant_obj),
         spidex_human=spidex_human(variant_obj),
         str_source_link=str_source_link(variant_obj),
+        snp_links=snp_links(variant_obj),
     )
     return links
 
@@ -420,7 +423,7 @@ def ensembl_link(variant_obj, build=37):
     """Compose (sv) variant link to ensembl"""
 
     my_end = variant_obj["end"]
-    if variant_obj["chromosome"] != variant_obj["end_chrom"]:
+    if variant_obj["chromosome"] != variant_obj.get("end_chrom", variant_obj["chromosome"]):
         my_end = variant_obj["position"]
 
     if build == 37:
@@ -434,7 +437,7 @@ def decipher_link(variant_obj, build=37):
     """Compose DECIPHER SV variant links"""
 
     my_end = variant_obj["end"]
-    if variant_obj["chromosome"] != variant_obj["end_chrom"]:
+    if variant_obj["chromosome"] != variant_obj.get("end_chrom", variant_obj["chromosome"]):
         my_end = variant_obj["position"]
 
     if build == 37:
@@ -455,20 +458,16 @@ def exac_link(variant_obj):
 
 
 def gnomad_link(variant_obj, build=37):
-    """Compose link to gnomAD website."""
+    """Compose link to gnomAD website for a variant."""
+    url_template = (
+        "http://gnomad.broadinstitute.org/variant/{this[chromosome]}-"
+        "{this[position]}-{this[reference]}-{this[alternative]}"
+    ).format(this=variant_obj)
 
-    if build == 38:
-        url_template = (
-            "http://gnomad.broadinstitute.org/variant/{this[chromosome]}-"
-            "{this[position]}-{this[reference]}-{this[alternative]}?dataset=gnomad_r3"
-        )
-    else:
-        url_template = (
-            "http://gnomad.broadinstitute.org/variant/{this[chromosome]}-"
-            "{this[position]}-{this[reference]}-{this[alternative]}"
-        )
+    if build == 38 or variant_obj["chromosome"] in ["M", "MT"]:
+        url_template += "?dataset=gnomad_r3"
 
-    return url_template.format(this=variant_obj)
+    return url_template
 
 
 def swegen_link(variant_obj):
@@ -522,6 +521,24 @@ def beacon_link(variant_obj, build=None):
     return url_template.format(this=variant_obj)
 
 
+def snp_links(variant_obj):
+    """Compose links to dbSNP and ClinVar variation"""
+
+    if variant_obj.get("dbsnp_id") is None:
+        return
+    snp_links = {}
+    snp_ids = variant_obj["dbsnp_id"].split(";")
+    for snp in snp_ids:
+        if "rs" in snp:
+            snp_links[snp] = f"https://www.ncbi.nlm.nih.gov/snp/{snp}"  # dbSNP
+        elif snp.isnumeric():
+            snp_links[
+                snp
+            ] = f"https://www.ncbi.nlm.nih.gov/clinvar/variation/{snp}"  # ClinVar variation
+
+    return snp_links
+
+
 def ucsc_link(variant_obj, build=None):
     """Compose link to UCSC."""
     build = build or 37
@@ -602,6 +619,12 @@ def alamut_link(variant_obj, build=None):
     return url_template.format(this=variant_obj, build_str=build_str)
 
 
+def mitomap_link(variant_obj):
+    """Compose a link to a variant in mitomap"""
+    url_template = "https://mitomap.org/cgi-bin/search_allele?variant={this[position]}{this[reference]}%3E{this[alternative]}"
+    return url_template.format(this=variant_obj)
+
+
 def spidex_human(variant_obj):
     """Translate SPIDEX annotation to human readable string."""
     if variant_obj.get("spidex") is None:
