@@ -1,8 +1,4 @@
-from scout.parse.variant.frequency import (
-    parse_frequency,
-    parse_frequencies,
-    parse_sv_frequencies,
-)
+from scout.parse.variant.frequency import parse_frequencies, parse_frequency, parse_sv_frequencies
 
 
 def test_parse_frequency(cyvcf2_variant):
