@@ -19,7 +19,7 @@ def hpo_term(gene_list):
 @pytest.fixture
 def gene_list():
     """A list of HGNC ids"""
-    gene_list = [26113, 9479, 10889, 18040, 10258]
+    gene_list = [26113, 9479, 10889, 18040, 10258, 1968]
     return gene_list
 
 
@@ -35,20 +35,23 @@ def panel():
         "genes": [
             {"hgnc_id": 234, "symbol": "ADK"},
             {"hgnc_id": 7481, "symbol": "MT-TF"},
+            {"hgnc_id": 1968, "symbol": "LYST"},
         ],
     }
     return panel_info
 
 
 @pytest.fixture
-def dummy_case():
+def dummy_case(panel):
     """Return a simple case"""
     case_info = {
         "case_id": "1",
+        "genome_build": 37,
         "owner": "cust000",
         "individuals": [
             {"analysis_type": "wgs", "sex": 1, "phenotype": 2, "individual_id": "ind1"}
         ],
         "status": "inactive",
+        "panels": [panel],
     }
     return case_info
