@@ -1,19 +1,15 @@
 # -*- coding: utf-8 -*-
 import datetime
-import requests
-from flask import url_for, current_app, jsonify
-from flask_login import current_user
 
+import requests
 from bson.objectid import ObjectId
+from flask import current_app, jsonify, url_for
+from flask_login import current_user
 
 from scout.demo import delivery_report_path
 from scout.server.blueprints.cases import controllers
-from scout.server.extensions import store
-from scout.server.extensions import mail
-from scout.server.blueprints.cases.views import (
-    parse_raw_gene_symbols,
-    parse_raw_gene_ids,
-)
+from scout.server.blueprints.cases.views import parse_raw_gene_ids, parse_raw_gene_symbols
+from scout.server.extensions import mail, store
 
 TEST_TOKEN = "test_token"
 
@@ -71,7 +67,7 @@ def test_parse_raw_gene_symbols(app):
 
 
 def test_parse_raw_gene_ids(app):
-    """ Test parse gene symbols"""
+    """Test parse gene symbols"""
 
     # GIVEN a list of autocompleted gene symbols
     gene_symbols = ["1234 | SYM (OLDSYM, SYM)", "4321 | MYS (OLDMYS, MYS)"]
@@ -303,7 +299,11 @@ def test_update_case_comment(app, institute_obj, case_obj, user_obj):
         assert comment
 
         # WHEN a user updates the comment via the modal form
-        form_data = {"event_id": comment["_id"], "updatedContent": "an updated comment", "edit": ""}
+        form_data = {
+            "event_id": comment["_id"],
+            "updatedContent": "an updated comment",
+            "edit": "",
+        }
         resp = client.post(
             url_for(
                 "cases.events",
@@ -334,13 +334,21 @@ def test_add_case_group(app, case_obj, institute_obj):
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
 
+        # Given a page referrer (request to add case group starts from case page)
+        referer = url_for(
+            "cases.case",
+            institute_id=institute_obj["internal_id"],
+            case_name=case_obj["display_name"],
+        )
+
         # WHEN we invoke the add group endpoint with GET
         resp = client.get(
             url_for(
                 "cases.add_case_group",
                 institute_id=institute_obj["_id"],
                 case_name=case_obj["display_name"],
-            )
+            ),
+            headers={"referer": referer},
         )
 
         # THEN the response should be a redirect
@@ -360,6 +368,13 @@ def test_remove_case_group(app, case_obj, institute_obj):
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
 
+        # Given a page referrer (request to remove case group starts from case page)
+        referer = url_for(
+            "cases.case",
+            institute_id=institute_obj["internal_id"],
+            case_name=case_obj["display_name"],
+        )
+
         # WHEN we invoke the add group endpoint with GET
         resp = client.get(
             url_for(
@@ -367,7 +382,8 @@ def test_remove_case_group(app, case_obj, institute_obj):
                 institute_id=institute_obj["_id"],
                 case_name=case_obj["display_name"],
                 case_group=group_id,
-            )
+            ),
+            headers={"referer": referer},
         )
 
         # THEN the response should be a redirect
@@ -379,7 +395,11 @@ def test_download_hpo_genes(app, case_obj, institute_obj):
 
     # GIVEN a case containing a dynamic gene list
     dynamic_gene_list = [
-        {"hgnc_symbol": "ACTA2", "hgnc_id": 130, "description": "actin alpha 2, smooth muscle"},
+        {
+            "hgnc_symbol": "ACTA2",
+            "hgnc_id": 130,
+            "description": "actin alpha 2, smooth muscle",
+        },
         {"hgnc_symbol": "LMNB2", "hgnc_id": 6638, "description": "lamin B2"},
     ]
 
@@ -399,6 +419,7 @@ def test_download_hpo_genes(app, case_obj, institute_obj):
                 "cases.download_hpo_genes",
                 institute_id=institute_obj["_id"],
                 case_name=case_obj["display_name"],
+                category="research",
             )
         )
         # THEN the response should be successful
@@ -473,6 +494,29 @@ def test_pdf_case_report(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
 
+def test_gene_fusion_report(app, institute_obj, case_obj):
+    """Test the endpoint that allows users to download the PDF file containing the gene fusion report."""
+    # GIVEN an initialized app and a valid user and institute
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # When clicking on gene fusion report link button on the sidebar
+        resp = client.get(
+            url_for(
+                "cases.gene_fusion_report",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+                report_type="gene_fusion_report",
+            )
+        )
+        # a successful response should be returned
+        assert resp.status_code == 200
+        # And the downloaded file should be a PDF file
+        assert resp.mimetype == "application/pdf"
+
+
 def test_mt_report(app, institute_obj, case_obj):
     # GIVEN an initialized app
     # GIVEN a valid user and institute
@@ -656,6 +700,27 @@ def test_status(app, institute_obj, case_obj, user_obj):
         assert resp.status_code == 302  # page should be redirected
 
 
+def _test_delivery_report(client, institute_obj, case_obj, response_format):
+    """Test helper: test report of given format"""
+
+    # WHEN the case has a delivery report
+    store.case_collection.update_one(
+        {"_id": case_obj["_id"]},
+        {"$set": {"delivery_report": delivery_report_path}},
+    )
+
+    # WHEN accessing the delivery report page with the format=pdf param
+    resp = client.get(
+        url_for(
+            "cases.delivery_report",
+            institute_id=institute_obj["internal_id"],
+            case_name=case_obj["display_name"],
+            format=response_format,
+        )
+    )
+    return resp
+
+
 def test_html_delivery_report(app, institute_obj, case_obj, user_obj):
 
     # GIVEN an initialized app
@@ -665,21 +730,7 @@ def test_html_delivery_report(app, institute_obj, case_obj, user_obj):
         resp = client.get(url_for("auto_login"))
         assert resp.status_code == 200
 
-        # AND the case has a delivery report
-        store.case_collection.update_one(
-            {"_id": case_obj["_id"]},
-            {"$set": {"delivery_report": delivery_report_path}},
-        )
-
-        # WHEN accessing the delivery report page
-        resp = client.get(
-            url_for(
-                "cases.delivery_report",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-            )
-        )
-
+        resp = _test_delivery_report(client, institute_obj, case_obj, response_format="html")
         # THEN the endpoint should return the delivery report HTML page
         assert "Leveransrapport Clinical Genomics" in str(resp.data)
 
@@ -693,22 +744,7 @@ def test_pdf_delivery_report(app, institute_obj, case_obj, user_obj):
         resp = client.get(url_for("auto_login"))
         assert resp.status_code == 200
 
-        # AND the case has a delivery report
-        store.case_collection.update_one(
-            {"_id": case_obj["_id"]},
-            {"$set": {"delivery_report": delivery_report_path}},
-        )
-
-        # WHEN accessing the delivery report page with the format=pdf param
-        resp = client.get(
-            url_for(
-                "cases.delivery_report",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-                format="pdf",
-            )
-        )
-
+        resp = _test_delivery_report(client, institute_obj, case_obj, response_format="pdf")
         # a successful response should be returned
         assert resp.status_code == 200
         # and it should contain a pdf file, not HTML code
@@ -729,7 +765,9 @@ def test_caselist(app, case_obj):
         # WHEN the API is invoked with a query string containing part of the case term description
         resp = client.get(
             url_for(
-                "cases.caselist", institute_id=case_obj["owner"], query=case_obj["display_name"]
+                "cases.caselist",
+                institute_id=case_obj["owner"],
+                query=case_obj["display_name"],
             )
         )
         # THEN it should return a valid response
@@ -759,6 +797,22 @@ def test_omimterms(app, test_omim_term):
 
         # containing the OMIM term
         assert test_omim_term["_id"] in str(resp.data)
+        assert resp.mimetype == "application/json"
+
+
+def _test_beacon_submit(client, case_obj, vcf_files):
+    """Test beacon connection: given client, produce response"""
+    form_data = {
+        "case": case_obj["_id"],
+        "samples": "affected",
+        "vcf_files": vcf_files,
+    }
+    # WHEN case page is loaded
+    resp = client.post(
+        url_for("cases.beacon_submit"),
+        data=form_data,
+    )
+    return resp
 
 
 def test_beacon_submit_wrong_config(app, case_obj):
@@ -770,20 +824,14 @@ def test_beacon_submit_wrong_config(app, case_obj):
         resp = client.get(url_for("auto_login"))
         assert resp.status_code == 200
 
-        form_data = {
-            "case": case_obj["_id"],
-            "samples": "affected",
-            "vcf_files": ["vcf_snv_research", "vcf_snv"],
-        }
-        # WHEN case page is loaded
-        resp = client.post(
-            url_for("cases.beacon_submit"),
-            data=form_data,
-        )
+        vcf_files = ["vcf_snv_research", "vcf_snv"]
+        # WHEN case page is loaded without beacon config settings
+        resp = _test_beacon_submit(client, case_obj, vcf_files)
+
         # THEN it should redirect to case page
         assert resp.status_code == 302
         updated_case = store.case_collection.find_one()
-        # and submission should not be saved in case object
+        # but submission should not be saved in case object
         assert "beacon" not in updated_case
 
 
@@ -805,23 +853,17 @@ def test_beacon_submit(app, case_obj, monkeypatch, mocked_beacon):
         resp = client.get(url_for("auto_login"))
         assert resp.status_code == 200
 
-        form_data = {
-            "case": case_obj["_id"],
-            "samples": "affected",
-            "vcf_files": ["vcf_snv_research", "vcf_snv"],
-        }
-        # WHEN users submits a POST request to Beacon
-        resp = client.post(
-            url_for("cases.beacon_submit"),
-            data=form_data,
-        )
+        vcf_files = ["vcf_snv_research", "vcf_snv"]
+        # WHEN case page is loaded
+        resp = _test_beacon_submit(client, case_obj, vcf_files)
+
         # THEN it should redirect to case page
         assert resp.status_code == 302
         updated_case = store.case_collection.find_one()
         # and submissions details should be saved in case object
         assert "beacon" in updated_case
         assert updated_case["beacon"]["samples"]
-        assert updated_case["beacon"]["vcf_files"] == form_data["vcf_files"]
+        assert updated_case["beacon"]["vcf_files"] == vcf_files
 
 
 def test_beacon_remove(app, case_obj, monkeypatch, mocked_beacon):
