@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 import datetime
+
 from flask import url_for
 from flask_login import current_user
+
 from scout.server.extensions import store
 
 TEST_SUBPANEL = dict(
@@ -188,9 +190,9 @@ def test_phenomodel_POST_add_delete_subpanel(app, user_obj, institute_obj):
         resp = client.get(url_for("auto_login"))
 
         form_data = dict(
-            title="Subpanel title",
-            subtitle="Subpanel subtitle",
-            add_subpanel="save subpanel",
+            title="Phenotype subpanel title",
+            subtitle="Phenotype subpanel subtitle",
+            add_subpanel="Save phenotype subpanel",
         )
         # WHEN the user creates subpanel in phenotype model via POST request
         resp = client.post(
@@ -204,8 +206,8 @@ def test_phenomodel_POST_add_delete_subpanel(app, user_obj, institute_obj):
         # Then the subpanel dictionary should be added to model subpanels
         updated_model = store.phenomodel_collection.find_one()
         subpanel_id = list(updated_model["subpanels"].keys())[0]
-        assert updated_model["subpanels"][subpanel_id]["title"] == "Subpanel title"
-        assert updated_model["subpanels"][subpanel_id]["subtitle"] == "Subpanel subtitle"
+        assert updated_model["subpanels"][subpanel_id]["title"] == "Phenotype subpanel title"
+        assert updated_model["subpanels"][subpanel_id]["subtitle"] == "Phenotype subpanel subtitle"
 
         # WHEN the user sends a POST request to remove the subpanel
         form_data = dict(subpanel_delete=subpanel_id)
@@ -768,7 +770,7 @@ def test_institute_users(app, institute_obj, user_obj):
 
 
 def test_clinvar_submissions(app, institute_obj, clinvar_variant, clinvar_casedata):
-    """"Test the web page containing the clinvar submissions for an institute"""
+    """Test the web page containing the clinvar submissions for an institute"""
 
     # GIVEN an institute with a clinvar submission
     store.create_submission(institute_obj["_id"])
@@ -820,6 +822,8 @@ def test_rename_clinvar_samples(app, institute_obj, clinvar_variant, clinvar_cas
             new_name="new_sample_name",
         )
 
+        referer = url_for("overview.clinvar_submissions", institute_id=institute_obj["internal_id"])
+
         # WHEN the sample name is edited from the submission page (POST request)
         resp = client.post(
             url_for(
@@ -829,6 +833,7 @@ def test_rename_clinvar_samples(app, institute_obj, clinvar_variant, clinvar_cas
                 old_name=old_name,
             ),
             data=form_data,
+            headers={"referer": referer},
         )
         # a successful response should be redirect to the submssions page
         assert resp.status_code == 302
