@@ -1,19 +1,45 @@
 import copy
 import logging
-from scout.constants import EXPORT_HEADER
-from scout.server.blueprints.variants.controllers import (
-    gene_panel_choices,
-    variants_export_header,
-    variant_export_lines,
-    variants,
-    sv_variants,
-)
 
 from bson.objectid import ObjectId
+from flask_wtf import FlaskForm
+from wtforms import SelectField
+
+from scout.constants import CHROMOSOMES_38, EXPORT_HEADER
+from scout.server.blueprints.variants.controllers import (
+    gene_panel_choices,
+    match_gene_txs_variant_txs,
+    populate_chrom_choices,
+    sv_variants,
+    variant_export_lines,
+    variants,
+    variants_export_header,
+)
 
 LOG = logging.getLogger(__name__)
 
 
+def test_populate_chrom_choices(app):
+    """Test the function that populates the choices of the chromosome select in variants filters"""
+
+    # GIVEN a variants filter form
+    with app.test_client() as client:
+
+        class TestForm(FlaskForm):
+            chrom = SelectField("Chromosome", choices=[], default="")
+
+        form = TestForm()
+
+    # IF the case build is 38
+    case = {"genome_build": "38"}
+    # THEN chromosome choices should correspond to genome build 38 chromosomes
+    populate_chrom_choices(form, case)
+    choices = form.chrom.choices
+
+    for nr, choice in enumerate(choices[1:]):  # first choice is not a chromosome, but all chroms
+        assert choice[0] == CHROMOSOMES_38[nr]
+
+
 def test_gene_panel_choices(institute_obj, case_obj):
     """test controller function that populates gene panel filter select"""
 
@@ -233,6 +259,48 @@ def test_sv_variants_research_shadow_clinical_assessments(
     assert any([variant.get("clinical_assessments") for variant in res_variants])
 
 
+def test_match_gene_txs_variant_txs():
+    """Test function matching gene and variant transcripts to export variants to file"""
+
+    variant_gene = {
+        "hgnc_id": 17284,
+        "transcripts": [
+            {
+                "transcript_id": "ENST00000357628",  # canonical
+                "coding_sequence_name": "c.903G>T",
+                "protein_sequence_name": "p.Gln301His",
+                "is_canonical": True,
+            },
+            {
+                "transcript_id": "ENST00000393329",  # primary
+                "coding_sequence_name": "c.510G>T",
+                "protein_sequence_name": "p.Gln170His",
+            },
+        ],
+    }
+    hgnc_gene = {
+        "hgnc_id": 17284,
+        "primary_transcripts": ["NM_001042594"],
+        "transcripts": [
+            {
+                "ensembl_transcript_id": "ENST00000357628",  # canonical
+                "refseq_identifiers": ["NM_015450"],
+                "refseq_id": "NM_015450",
+            },
+            {
+                "ensembl_transcript_id": "ENST00000393329",  # primary
+                "is_primary": True,
+                "refseq_identifiers": ["NM_001042594"],
+                "refseq_id": "NM_001042594",
+            },
+        ],
+    }
+
+    canonical_txs, primary_txs = match_gene_txs_variant_txs(variant_gene, hgnc_gene)
+    assert canonical_txs == ["NM_015450/c.903G>T/p.Gln301His"]
+    assert primary_txs == ["NM_001042594/c.510G>T/p.Gln170His"]
+
+
 def test_variant_csv_export(real_variant_database, case_obj):
     adapter = real_variant_database
     case_id = case_obj["_id"]
