@@ -49,7 +49,10 @@ def test_send_gene_request(ensembl_gene_response, ensembl_rest_client_37):
     url = "https://grch37.rest.ensembl.org/overlap/id/ENSG00000103591?feature=gene"
     client = ensembl_rest_client_37
     responses.add(
-        responses.GET, url, json=ensembl_gene_response, status=200,
+        responses.GET,
+        url,
+        json=ensembl_gene_response,
+        status=200,
     )
     data = client.send_request(url)
 
@@ -63,14 +66,17 @@ def test_send_gene_request(ensembl_gene_response, ensembl_rest_client_37):
 @responses.activate
 def test_send_request_fakey_url(ensembl_rest_client_37):
     """Successful requests are tested by other tests in this file.
-       This test will trigger errors instead.
+    This test will trigger errors instead.
     """
     # GIVEN a completely invalid URL
     url = "fakeyurl"
     # GIVEN a client
     client = ensembl_rest_client_37
     responses.add(
-        responses.GET, url, body=MissingSchema(), status=404,
+        responses.GET,
+        url,
+        body=MissingSchema(),
+        status=404,
     )
     data = client.send_request(url)
     assert isinstance(data, MissingSchema)
@@ -79,12 +85,15 @@ def test_send_request_fakey_url(ensembl_rest_client_37):
 @responses.activate
 def test_send_request_wrong_url(ensembl_rest_client_37):
     """Successful requests are tested by other tests in this file.
-       This test will trigger errors instead.
+    This test will trigger errors instead.
     """
     url = "https://grch37.rest.ensembl.org/fakeyurl"
     client = ensembl_rest_client_37
     responses.add(
-        responses.GET, url, body=HTTPError(), status=404,
+        responses.GET,
+        url,
+        body=HTTPError(),
+        status=404,
     )
     data = client.send_request(url)
     assert isinstance(data, HTTPError)
@@ -99,7 +108,10 @@ def test_use_api(ensembl_rest_client_38, ensembl_transcripts_response):
     client = ensembl_rest_client_38
     url = client.build_url(endpoint, params)
     responses.add(
-        responses.GET, url, json=ensembl_transcripts_response, status=200,
+        responses.GET,
+        url,
+        json=ensembl_transcripts_response,
+        status=200,
     )
 
     # get all transctipts for an ensembl gene, They should be a list of items
@@ -122,13 +134,9 @@ def test_xml_filters(ensembl_biomart_client_37):
 
     # make sure lines are formatted as they should
     assert (
-        '<Filter name = "{0}" value = "{1}"/>'.format("string_filter", "string_value")
-        in xml_lines
-    )
-    assert (
-        '<Filter name = "{0}" value = "{1}"/>'.format("list_filter", "1,X,MT")
-        in xml_lines
+        '<Filter name = "{0}" value = "{1}"/>'.format("string_filter", "string_value") in xml_lines
     )
+    assert '<Filter name = "{0}" value = "{1}"/>'.format("list_filter", "1,X,MT") in xml_lines
 
 
 def test_xml_attributes(ensembl_biomart_client_37):
@@ -147,7 +155,7 @@ def test_xml_attributes(ensembl_biomart_client_37):
 @responses.activate
 def test_test_query_biomart_38_xml(ensembl_biomart_xml_query):
     """Prepare a test xml document for the biomart service build 38
-     and query the service using it
+    and query the service using it
     """
     # GIVEN client with a xml query for a gene
     build = "38"
