@@ -1,9 +1,12 @@
+import uuid
+
 import requests
+
 from scout.utils.matchmaker import mme_nodes
 
 
 def test_mme_nodes(monkeypatch):
-    """ Test the function that returns the connected MatchMaker nodes """
+    """Test the function that returns the connected MatchMaker nodes"""
 
     # GIVEN a monkeypatched connection to a MME server connected with 2 other nodes
     class MockResponse(object):
@@ -23,7 +26,7 @@ def test_mme_nodes(monkeypatch):
 
     # WHEN Scout asks for connected nodes
     mme_base_url = "fakeynode.se"
-    token = "test_token"
+    token = str(uuid.uuid4())
     nodes = mme_nodes(mme_base_url, token)
     # Then 2 nodes should be returned
     assert len(nodes) == 2
